@@ -28,7 +28,7 @@ class LinesCollection:
     def __setitem__(self, key: Path, value: list[str]) -> None:
         self._data[key] = value
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return True
 
     def __getattr__(self, name: str, default: Any = None) -> Any:
@@ -44,7 +44,7 @@ class LinesCollection:
         return getattr(self._data, name, default)
 
     # TODO: remove once Python 3.7 support is dropped
-    @lru_cache(maxsize=None)
+    @lru_cache(maxsize=None)  # noqa: B019
     def tokens(self, path: Path) -> tuple[list[tokenize.TokenInfo], defaultdict]:
         """Tokenize the code.
 
@@ -69,7 +69,7 @@ class ModulesCollection(GetMembersMixin, SetCollectionMembersMixin):
         """Initialize the collection."""
         self.members: dict[str, Module] = {}
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return True
 
     def __contains__(self, item: Any) -> bool:
